@@ -16,18 +16,17 @@
 from os import path
 import sys
 
-from cliff import command
-from cliff import lister
-from openstackclient.common import exceptions
-from openstackclient.common import utils as osc_utils
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils as osc_utils
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
+from saharaclient.osc import utils
 from saharaclient.osc.v1.job_templates import JOB_TYPES_CHOICES
-from saharaclient.osc.v1 import utils
 
 
-class ListJobTypes(lister.Lister):
+class ListJobTypes(command.Lister):
     """Lists job types supported by plugins"""
 
     log = logging.getLogger(__name__ + ".ListJobTypes")
@@ -56,7 +55,7 @@ class ListJobTypes(lister.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         search_opts = {}
@@ -114,7 +113,7 @@ class GetJobTypeConfigs(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         if not parsed_args.file:
