@@ -13,9 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
-
 from osc_lib.tests import utils as osc_utils
+from unittest import mock
 
 from saharaclient.api import images as api_images
 from saharaclient.osc.v1 import images as osc_images
@@ -33,6 +32,7 @@ class TestImages(fakes.TestDataProcessing):
         self.image_mock = (
             self.app.client_manager.data_processing.images)
         self.image_mock.reset_mock()
+        self.app.api_version['data_processing'] = '1'
 
 
 class TestListImages(TestImages):
@@ -176,8 +176,8 @@ class TestRegisterImage(TestImages):
         self.image_mock.update_image.return_value = mock.Mock(
             image=IMAGE_INFO.copy())
         self.app.client_manager.image = mock.Mock()
-        self.image_client = self.app.client_manager.image.images
-        self.image_client.get.return_value = mock.Mock(id='id')
+        self.image_client = self.app.client_manager.image
+        self.image_client.find_image.return_value = mock.Mock(id='id')
 
         # Command to test
         self.cmd = osc_images.RegisterImage(self.app, None)
